==> vxe-table-helper-0.1.4.tgz: package/es/table/base.js <==
var __defProp = Object.defineProperty;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __publicField = (obj, key, value) => {
  __defNormalProp(obj, typeof key !== "symbol" ? key + "" : key, value);
  return value;
};
import { reactive, ref } from "vue";
import { useToggle, get } from "@vueuse/core";
import { cloneDeep, merge, set, isFunction, assign } from "lodash-es";
import { defaultOptions } from "./config.js";
class BaseTable {
  constructor(options) {
    __publicField(this, "_options");
    __publicField(this, "_loading");
    __publicField(this, "_toggleLoading");
    __publicField(this, "_filters");
    __publicField(this, "_api");
    __publicField(this, "fetchData", (data = {}) => {
      var _a, _b;
      if (!this._api.query)
        throw new Error("\u8868\u683C\u672A\u521D\u59CB\u5316\u83B7\u53D6\u6570\u636E\u63A5\u53E3, \u8BF7\u5148\u8C03\u7528 setApi \u65B9\u6CD5\u5B8C\u6210\u63A5\u53E3\u521D\u59CB\u5316!");
      if (!isFunction(this._api.query.fn))
        throw new Error("\u67E5\u8BE2\u63A5\u53E3\u51FD\u6570\u5FC5\u987B\u662F\u4E00\u4E2APromise\u51FD\u6570");
      this._toggleLoading(true);
      let params = {};
      if ((_a = this._options.pagerConfig) == null ? void 0 : _a.enabled) {
        params = {
          [this._options.pagerConfig.pageKey]: this._options.pagerConfig.currentPage,
          [this._options.pagerConfig.pageSizeKey]: this._options.pagerConfig.pageSize
        };
      }
      params = assign(params, get(this._filters), data);
      if ((_b = this._api.query.hooks) == null ? void 0 : _b.before) {
        const refactoryParams = this._api.query.hooks.before(params);
        if (refactoryParams)
          params = refactoryParams;
      }
      this._api.query.fn(params).then((result) => {
        var _a2;
        if ((_a2 = this._api.query.hooks) == null ? void 0 : _a2.success) {
          this._api.query.hooks.success(result, this._options);
        }
      }).catch((reason) => {
        var _a2;
        if ((_a2 = this._api.query.hooks) == null ? void 0 : _a2.error)
          this._api.query.hooks.error(reason, this._options);
      }).finally(() => this._toggleLoading(false));
    });
    __publicField(this, "use", () => reactive({
      tableOptions: this._options,
      tableLoading: this._loading,
      fetchData: this.fetchData
    }));
    var _a, _b, _c, _d, _e;
    const [loading, toggleLoading] = useToggle(false);
    this._loading = loading;
    this._toggleLoading = toggleLoading;
    this._options = reactive(cloneDeep(merge({ loading: this._loading }, defaultOptions, options)));
    this._filters = (_b = (_a = this._options) == null ? void 0 : _a.filters) != null ? _b : ref({});
    this._api = (_d = (_c = this._options) == null ? void 0 : _c.api) != null ? _d : {};
    if (!((_e = this._options) == null ? void 0 : _e.onPageChange))
      this._initPagerEvents();
  }
  setData(data) {
    this._options.data = data;
    return this;
  }
  getData() {
    return this._options.data;
  }
  setColumns(columns) {
    this._options.columns = columns;
    return this;
  }
  _initPagerEvents() {
    this._options.onPageChange = ({ type, currentPage, pageSize }) => {
      switch (type) {
        case "current":
          this._options.pagerConfig.currentPage = currentPage;
          this.fetchData({
            [this._options.pagerConfig.pageKey]: currentPage,
            [this._options.pagerConfig.pageSizeKey]: pageSize
          });
          break;
        case "size":
          this._options.pagerConfig.pageSize = pageSize;
          this.fetchData({
            [this._options.pagerConfig.pageKey]: 1,
            [this._options.pagerConfig.pageSizeKey]: pageSize
          });
          break;
      }
    };
  }
  setPager(pager) {
    this._options.pagerConfig = pager;
    return this;
  }
  getPager() {
    return this._options.pagerConfig;
  }
  setFilters(filters) {
    this._filters = ref(filters);
    return this;
  }
  setApi(params) {
    set(this._api, "query", params);
  }
}
export {
  BaseTable
};

==> vxe-table-helper-0.1.5.tgz: package/es/table/base.js <==
var __defProp = Object.defineProperty;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __publicField = (obj, key, value) => {
  __defNormalProp(obj, typeof key !== "symbol" ? key + "" : key, value);
  return value;
};
import { reactive, ref } from "vue";
import { useToggle, get } from "@vueuse/core";
import { cloneDeep, merge, set, isFunction, assign } from "lodash-es";
import { defaultOptions } from "./config.js";
class BaseTable {
  constructor(options) {
    __publicField(this, "_options");
    __publicField(this, "_loading");
    __publicField(this, "_toggleLoading");
    __publicField(this, "_filters");
    __publicField(this, "_api");
    __publicField(this, "fetchData", (data = {}) => {
      var _a, _b;
      if (!this._api.query)
        throw new Error("\u8868\u683C\u672A\u521D\u59CB\u5316\u83B7\u53D6\u6570\u636E\u63A5\u53E3, \u8BF7\u5148\u8C03\u7528 setApi \u65B9\u6CD5\u5B8C\u6210\u63A5\u53E3\u521D\u59CB\u5316!");
      if (!isFunction(this._api.query.fn))
        throw new Error("\u67E5\u8BE2\u63A5\u53E3\u51FD\u6570\u5FC5\u987B\u662F\u4E00\u4E2APromise\u51FD\u6570");
      this._toggleLoading(true);
      let params = {};
      if ((_a = this._options.pagerConfig) == null ? void 0 : _a.enabled) {
        params = {
          [this._options.pagerConfig.pageKey]: this._options.pagerConfig.currentPage,
          [this._options.pagerConfig.pageSizeKey]: this._options.pagerConfig.pageSize
        };
      }
      params = assign(params, get(this._filters), data);
      if ((_b = this._api.query.hooks) == null ? void 0 : _b.before) {
        const refactoryParams = this._api.query.hooks.before(params);
        if (refactoryParams)
          params = refactoryParams;
      }
      this._api.query.fn(params).then((result) => {
        var _a2;
        if ((_a2 = this._api.query.hooks) == null ? void 0 : _a2.success) {
          this._api.query.hooks.success(result, this._options);
        }
      }).catch((reason) => {
        var _a2;
        if ((_a2 = this._api.query.hooks) == null ? void 0 : _a2.error)
          this._api.query.hooks.error(reason, this._options);
      }).finally(() => this._toggleLoading(false));
    });
    __publicField(this, "use", () => ({
      tableOptions: this._options,
      tableLoading: this._loading,
      fetchData: this.fetchData
    }));
    var _a, _b, _c, _d, _e;
    const [loading, toggleLoading] = useToggle(false);
    this._loading = loading;
    this._toggleLoading = toggleLoading;
    this._options = reactive(cloneDeep(merge({}, defaultOptions, options)));
    this._options.loading = loading;
    this._filters = (_b = (_a = this._options) == null ? void 0 : _a.filters) != null ? _b : ref({});
    this._api = (_d = (_c = this._options) == null ? void 0 : _c.api) != null ? _d : {};
    if (!((_e = this._options) == null ? void 0 : _e.onPageChange))
      this._initPagerEvents();
  }
  setData(data) {
    this._options.data = data;
    return this;
  }
  getData() {
    return this._options.data;
  }
  setColumns(columns) {
    this._options.columns = columns;
    return this;
  }
  _initPagerEvents() {
    this._options.onPageChange = ({ type, currentPage, pageSize }) => {
      switch (type) {
        case "current":
          this._options.pagerConfig.currentPage = currentPage;
          this.fetchData({
            [this._options.pagerConfig.pageKey]: currentPage,
            [this._options.pagerConfig.pageSizeKey]: pageSize
          });
          break;
        case "size":
          this._options.pagerConfig.pageSize = pageSize;
          this.fetchData({
            [this._options.pagerConfig.pageKey]: 1,
            [this._options.pagerConfig.pageSizeKey]: pageSize
          });
          break;
      }
    };
  }
  setPager(pager) {
    this._options.pagerConfig = pager;
    return this;
  }
  getPager() {
    return this._options.pagerConfig;
  }
  setFilters(filters) {
    this._filters = ref(filters);
    return this;
  }
  setApi(params) {
    set(this._api, "query", params);
  }
}
export {
  BaseTable
};
